@@ -410,6 +410,65 @@ class BuildDynamoDBTableProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.BuildDynamoDBTableWithStreamProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "dynamo_table_props": "dynamoTableProps",
+        "existing_table_interface": "existingTableInterface",
+    },
+)
+class BuildDynamoDBTableWithStreamProps:
+    def __init__(
+        self,
+        *,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
+    ) -> None:
+        '''
+        :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
+        :param existing_table_interface: Existing instance of dynamodb table object. Providing both this and ``dynamoTableProps`` will cause an error. Default: - None
+        '''
+        if isinstance(dynamo_table_props, dict):
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+        self._values: typing.Dict[str, typing.Any] = {}
+        if dynamo_table_props is not None:
+            self._values["dynamo_table_props"] = dynamo_table_props
+        if existing_table_interface is not None:
+            self._values["existing_table_interface"] = existing_table_interface
+
+    @builtins.property
+    def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
+        '''Optional user provided props to override the default props.
+
+        :default: - Default props are used
+        '''
+        result = self._values.get("dynamo_table_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
+
+    @builtins.property
+    def existing_table_interface(self) -> typing.Optional[aws_cdk.aws_dynamodb.ITable]:
+        '''Existing instance of dynamodb table object.
+
+        Providing both this and ``dynamoTableProps`` will cause an error.
+
+        :default: - None
+        '''
+        result = self._values.get("existing_table_interface")
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.ITable], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "BuildDynamoDBTableWithStreamProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildGlueJobProps",
     jsii_struct_bases=[],
@@ -1611,7 +1670,6 @@ class SinkStoreType(enum.Enum):
         "queue_props": "queueProps",
         "secret_props": "secretProps",
         "topic_props": "topicProps",
-        "topics_props": "topicsProps",
         "vpc_props": "vpcProps",
     },
 )
@@ -1645,7 +1703,6 @@ class VerifiedProps:
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         secret_props: typing.Optional[aws_cdk.aws_secretsmanager.SecretProps] = None,
         topic_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
-        topics_props: typing.Optional[aws_cdk.aws_sns.TopicProps] = None,
         vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
@@ -1675,7 +1732,6 @@ class VerifiedProps:
         :param queue_props: -
         :param secret_props: -
         :param topic_props: -
-        :param topics_props: -
         :param vpc_props: -
         '''
         if isinstance(bucket_props, dict):
@@ -1702,8 +1758,6 @@ class VerifiedProps:
             secret_props = aws_cdk.aws_secretsmanager.SecretProps(**secret_props)
         if isinstance(topic_props, dict):
             topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
-        if isinstance(topics_props, dict):
-            topics_props = aws_cdk.aws_sns.TopicProps(**topics_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         self._values: typing.Dict[str, typing.Any] = {}
@@ -1759,8 +1813,6 @@ class VerifiedProps:
             self._values["secret_props"] = secret_props
         if topic_props is not None:
             self._values["topic_props"] = topic_props
-        if topics_props is not None:
-            self._values["topics_props"] = topics_props
         if vpc_props is not None:
             self._values["vpc_props"] = vpc_props
 
@@ -1902,11 +1954,6 @@ class VerifiedProps:
         result = self._values.get("topic_props")
         return typing.cast(typing.Optional[aws_cdk.aws_sns.TopicProps], result)
 
-    @builtins.property
-    def topics_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
-        result = self._values.get("topics_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sns.TopicProps], result)
-
     @builtins.property
     def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
         result = self._values.get("vpc_props")
@@ -1928,6 +1975,7 @@ __all__ = [
     "AddProxyMethodToApiResourceInputParams",
     "BuildDeadLetterQueueProps",
     "BuildDynamoDBTableProps",
+    "BuildDynamoDBTableWithStreamProps",
     "BuildGlueJobProps",
     "BuildKinesisAnalyticsAppProps",
     "BuildKinesisStreamProps",
